clear all
clear matrix
set type double, perm
set varabbrev off, perm
set more off, perm
*cd ".../OII_code_and_data/"


*Figure 1 is in the ipynb

*Figure 2:
use Russell_June_panel, clear
keep if year ==2007
tab cutoff
gen switcher = (R2000==1 & l_R2000==0)
replace switcher = - 1 if (R2000==0 & l_R2000==1)
keep if caprank < 500 & caprank >=-500
replace caprank = caprank +cutoff
replace upper_band_caprank = upper_band_caprank + cutoff
replace lower_band_caprank = lower_band_caprank + cutoff
su cutoff upper_band_caprank lower_band_caprank
twoway (scatter R2000 caprank if switcher==0, mcolor(eltblue) xlab(#10) ///
        xline(836, lcolor(gs1) lpat(dash)) xline(1223, lcolor(gs1) lpat(dash)) xline(1010, lwidth(0.5) lcolor(black))) ///
       (scatter R2000 caprank if switcher!=0, msize(vlarge) m(X) mcolor(edkblue)), ///
       ytitle(Assigned to Russell 2000) xtitle(Mkt. Cap. Rank) ylab(#1, nogrid) ///
	   legend(lab(1 "Stayers") lab(2 "Switchers")) graphregion(color(white))
graph export Figure2.pdf, replace


*Figure 3:
use Russell_June_panel, clear
keep if year ==2007
*drop if l_R2000==.
gen upper = (caprank <= 0)
gen switcher = (R2000==1 & l_R2000==0)
replace switcher = - 1 if (R2000==0 & l_R2000==1)
gen potential_switcher = (upper==1 & l_R2000==1) | (upper==0 & l_R2000==0)
keep if potential_switcher==1
keep if (caprank_rel_to_upper <= 100 & caprank_rel_to_upper >= -99) | ///
 (caprank_rel_to_lower <= 100 & caprank_rel_to_lower >= -99)
replace caprank = caprank + cutoff
twoway (scatter R2000 caprank if switcher==0, mcolor(eltblue) xlab(#10) ///
        xline(836, lcolor(gs1) lpat(dash)) xline(1223, lcolor(gs1) lpat(dash)) xline(1000, lwidth(0.5) lcolor(black))) ///
       (scatter R2000 caprank if switcher!=0, msize(vlarge) m(X) mcolor(edkblue)), ///
       ytitle(Assigned to Russell 2000) xtitle(Mkt. Cap. Rank) ylab(#1, nogrid) ///
	   legend(lab(1 "Stayers") lab(2 "Switchers")) xscale(range(500 1500)) graphregion(color(white))
graph export Figure3.pdf, replace





*Figure 4:
use RDDpanel100_quarterly, replace
keep if upper==0
collapse (mean) MFpassive (sem) se_MFpassive = MFpassive, by(rel_qtr switch_in)
reshape wide MFpassive se_MFpassive, i(rel_qtr) j(switch_in)
gen MFpassive1_ub = MFpassive1 + se_MFpassive1 * 2
gen MFpassive1_lb = MFpassive1 - se_MFpassive1 * 2
gen MFpassive0_ub = MFpassive0 + se_MFpassive0 * 2
gen MFpassive0_lb = MFpassive0 - se_MFpassive0 * 2
line MFpassive0 rel_qtr, lwidth(0.9) lcolor(orange) || ///
rcap MFpassive0_ub MFpassive0_lb rel_qtr, lcolor(black) || ///
line MFpassive1 rel_qtr, lwidth(0.9) lcolor(edkblue) || ///
rcap MFpassive1_ub MFpassive1_lb rel_qtr, lcolor(black) ///
 legend(order(1 3) lab(1 "Stayers") lab(3 "Switchers"))  ///
 ytitle("Passive Fund Ownership (% of mkt cap)") ///
 xline(0, lpattern(dash) lcolor(black)) ///
 graphregion(color(white)) ///
 xtitle("Relative Quarter")
graph export Figure4a.pdf, replace



use RDDpanel100_quarterly, replace
keep if upper==1
collapse (mean) MFpassive (sem) se_MFpassive = MFpassive, by(rel_qtr switch_out)
reshape wide MFpassive se_MFpassive, i(rel_qtr) j(switch_out)
gen MFpassive1_ub = MFpassive1 + se_MFpassive1 * 2
gen MFpassive1_lb = MFpassive1 - se_MFpassive1 * 2
gen MFpassive0_ub = MFpassive0 + se_MFpassive0 * 2
gen MFpassive0_lb = MFpassive0 - se_MFpassive0 * 2
line MFpassive0 rel_qtr, lwidth(0.9) lcolor(orange) || ///
rcap MFpassive0_ub MFpassive0_lb rel_qtr, lcolor(black) || ///
line MFpassive1 rel_qtr, lwidth(0.9) lcolor(edkblue) || ///
rcap MFpassive1_ub MFpassive1_lb rel_qtr, lcolor(black) ///
 legend(order(1 3) lab(1 "Stayers") lab(3 "Switchers"))  ///
 ytitle("Passive Fund Ownership (% of mkt cap)") ///
 xline(0, lpattern(dash) lcolor(black)) ///
 graphregion(color(white)) ///
 xtitle("Relative Quarter")
graph export Figure4b.pdf, replace



*Figure 5:
use time_series_means, replace
twoway (line MVR4_ year, lcolor(orange) lwidth(0.7) lpattern(dash) yaxis(2)  ///
       yscale(range(-0.3 1.4) axis(2)) ylabel(1.0(0.2)1.4, axis(2) grid)) ///
(line MVR4_wt year, lcolor(orange) lwidth(0.6) yaxis(2)  ///
       yscale(range(-0.3 1.4) axis(2)) ytitle("") ylabel(1.0(0.2)1.4, axis(2) grid)) ///
       (line MFpassive year, lcolor(edkblue) lwidth(0.7) lpattern(dash) yscale(range(2 20) axis(1)) ylabel(0(2)12) yaxis(1)) ///
       (line MFpassive_wt year, lcolor(edkblue) lwidth(0.6) yscale(range(2 20) axis(1)) ylabel(0(2)12) yaxis(1)), ///
	   xscale(range(2007(1)2016)) graphregion(color(white)) xlabel(2007(1)2016) xtitle("") ytitle("") ///
	   legend(off) text(7 2014 "Passive Fund Ownership" "(% of Market Cap)") text(19.4 2009.5 "Variance Ratio")
graph export Figure5.pdf, replace


















*Table 1:
use RDDpanel100_quarterly, replace
*summary stats: keep only May observations just prior to index reconstitution
keep if rel_qtr==-1
gen month = 5
merge 1:m stockid year month using RDDpanel100_monthly, keep(match master) nogen
duplicates drop stockid year month, force 
replace May_mktcap = May_mktcap / 1000000
*
tabstat May_mktcap MFpassive MFactive MFtotal logturn logvlt short_prct corr_R1000 corr_R2000 mktbeta logsvi log_nreqs log_numest if upper==0, c(s) s(mean sd p10 p50 p90 n) save
tabstatmat sumstat
forvalues i=1/20{
	forvalues j = 1/20 {
qui cap matrix sumstat[`i' ,`j'] = round(sumstat[`i',`j'], .01)
}
}
matrix sumstatp = sumstat'
esttab matrix(sumstatp) using Table1_lower.tex, replace
*
tabstat May_mktcap MFpassive MFactive MFtotal logturn logvlt short_prct corr_R1000 corr_R2000 mktbeta logsvi log_nreqs log_numest if upper==1, c(s) s(mean sd p10 p50 p90 n) save
tabstatmat sumstat
forvalues i=1/20{
	forvalues j = 1/20 {
qui cap matrix sumstat[`i' ,`j'] = round(sumstat[`i',`j'], .01)
}
}
matrix sumstatp = sumstat'
esttab matrix(sumstatp) using Table1_upper.tex, replace







*Table 2:
use RDDpanel100_quarterly, replace
*upper band:
preserve
keep if upper==1
reghdfe MF_R2000 c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes) replace
reghdfe MF_R1000 c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFpassive c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFactive c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFtotal c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe all13F c.switch_out#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_upper, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
restore
*lower band:
preserve
keep if upper==0
reghdfe MF_R2000 c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes) replace
reghdfe MF_R1000 c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFpassive c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFactive c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe MFtotal c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe all13F c.switch_in#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)
outreg2 using Table2_lower, adjr tex(frag) bdec(2) tdec(1) tstat nocons addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
restore







*Table 3:
use RDDpanel100_monthly, replace
*upper band:
reghdfe logturn c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes) replace
reghdfe short_prct c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe logvlt c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe corr_R1000 c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe corr_R2000 c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe mktbeta c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
*lower band:
reghdfe logturn c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes) replace
reghdfe short_prct c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe logvlt c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe corr_R1000 c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe corr_R2000 c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe mktbeta c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table3_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)








**Table 4:
use RDDpanel100_monthly, clear
reghdfe logsvi c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes) replace
reghdfe logsvi c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes) replace
reghdfe log_nreqs c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
reghdfe log_nreqs c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Month FE, Yes)
*analyst coverage
use RDDpanel100_quarterly, replace
reghdfe log_numest c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearqtr) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe log_numest c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearqtr) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table4_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.8, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)




*Pooled estimates using Poisson instead of log(1+y):
use RDDpanel100_monthly, replace
ppmlhdfe SVI c.switch#c.posttreat, a(stockid#cohort yearmonth) cl(stockid)
ppmlhdfe nreqs c.switch#c.posttreat, a(stockid#cohort yearmonth) cl(stockid)
use RDDpanel100_quarterly, replace
ppmlhdfe numest c.switch#c.posttreat, a(stockid#cohort yearqtr) cl(stockid)







*Table 5:
use RDDpanel100_monthly, replace
*upper
reghdfe AMVR4_ c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes) replace
reghdfe AMVR8_ c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe avg_score c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe ret_sue_beta c.switch_out#c.posttreat if upper==1, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_upper, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
*lower
reghdfe AMVR4_ c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes) replace
reghdfe AMVR8_ c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe avg_score c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)
reghdfe ret_sue_beta c.switch_in#c.posttreat if upper==0, a(stockid#cohort yearmonth) cl(stockid)
local se = sqrt(e(V)[1, 1])
outreg2 using Table5_lower, adjr2 tex(frag) stats(coef tstat) bdec(3) tdec(1) br(tstat) addstat(MDES, `se' * 2.772, Sample StDev, sqrt(e(tss) / (e(N) - 1))) addtext(Stock x Cohort FE, Yes, Year x Quarter FE, Yes)




